////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  ltm_1_3_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "ltm_1_3_0.h"
#include "parametersetmanager.h"

LTM_1_3_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ltm13_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "la_curve_tab") == 0)
    {
        __result = la_curve_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ltm_scale_tab") == 0)
    {
        __result = ltm_scale_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lce_scale_pos_tab") == 0)
    {
        __result = lce_scale_pos_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lce_scale_neg_tab") == 0)
    {
        __result = lce_scale_neg_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "y_ratio_max") == 0)
    {
        ParameterUtils::DoubleToString((double)y_ratio_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ltm_strength") == 0)
    {
        ParameterUtils::DoubleToString((double)ltm_strength, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "exp_atten_start") == 0)
    {
        ParameterUtils::DoubleToString((double)exp_atten_start, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "exp_atten_end") == 0)
    {
        ParameterUtils::DoubleToString((double)exp_atten_end, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dark_boost") == 0)
    {
        ParameterUtils::DoubleToString((double)dark_boost, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "bright_suppress") == 0)
    {
        ParameterUtils::DoubleToString((double)bright_suppress, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lce_strength") == 0)
    {
        ParameterUtils::DoubleToString((double)lce_strength, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "p0") == 0)
    {
        ParameterUtils::DoubleToString((double)p0, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "p1") == 0)
    {
        ParameterUtils::DoubleToString((double)p1, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dark_range") == 0)
    {
        ParameterUtils::DoubleToString((double)dark_range, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "bright_range") == 0)
    {
        ParameterUtils::DoubleToString((double)bright_range, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dark_max") == 0)
    {
        ParameterUtils::DoubleToString((double)dark_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "bright_max") == 0)
    {
        ParameterUtils::DoubleToString((double)bright_max, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dark_gamma") == 0)
    {
        ParameterUtils::DoubleToString((double)dark_gamma, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "bright_gamma") == 0)
    {
        ParameterUtils::DoubleToString((double)bright_gamma, __value, __size);
        __result = true;
    }

    return __result;
}

bool ltm13_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "la_curve_tab") == 0)
    {
        __result = la_curve_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ltm_scale_tab") == 0)
    {
        __result = ltm_scale_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lce_scale_pos_tab") == 0)
    {
        __result = lce_scale_pos_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lce_scale_neg_tab") == 0)
    {
        __result = lce_scale_neg_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "y_ratio_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            y_ratio_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ltm_strength") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ltm_strength = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "exp_atten_start") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            exp_atten_start = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "exp_atten_end") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            exp_atten_end = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dark_boost") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dark_boost = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "bright_suppress") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            bright_suppress = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lce_strength") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lce_strength = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "p0") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            p0 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "p1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            p1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dark_range") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dark_range = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "bright_range") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            bright_range = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dark_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dark_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "bright_max") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            bright_max = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dark_gamma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dark_gamma = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "bright_gamma") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            bright_gamma = (float)dblValue; 
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // la_curve_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("la_curve_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "la_curve_tab") == 0)
    {
        __result = la_curve_tab.GetInfo(&__path[__pos], __info);
    }

    // ltm_scale_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_scale_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ltm_scale_tab") == 0)
    {
        __result = ltm_scale_tab.GetInfo(&__path[__pos], __info);
    }

    // lce_scale_pos_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lce_scale_pos_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lce_scale_pos_tab") == 0)
    {
        __result = lce_scale_pos_tab.GetInfo(&__path[__pos], __info);
    }

    // lce_scale_neg_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lce_scale_neg_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lce_scale_neg_tab") == 0)
    {
        __result = lce_scale_neg_tab.GetInfo(&__path[__pos], __info);
    }

    // y_ratio_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("y_ratio_max", ParameterParserDataType::Float, (double)y_ratio_max));
    }
    else if (PARAMETER_STRCMP(__name, "y_ratio_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)y_ratio_max));
    }

    // ltm_strength
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_strength", ParameterParserDataType::Float, (double)ltm_strength));
    }
    else if (PARAMETER_STRCMP(__name, "ltm_strength") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)ltm_strength));
    }

    // exp_atten_start
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("exp_atten_start", ParameterParserDataType::Float, (double)exp_atten_start));
    }
    else if (PARAMETER_STRCMP(__name, "exp_atten_start") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)exp_atten_start));
    }

    // exp_atten_end
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("exp_atten_end", ParameterParserDataType::Float, (double)exp_atten_end));
    }
    else if (PARAMETER_STRCMP(__name, "exp_atten_end") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)exp_atten_end));
    }

    // dark_boost
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dark_boost", ParameterParserDataType::Float, (double)dark_boost));
    }
    else if (PARAMETER_STRCMP(__name, "dark_boost") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dark_boost));
    }

    // bright_suppress
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("bright_suppress", ParameterParserDataType::Float, (double)bright_suppress));
    }
    else if (PARAMETER_STRCMP(__name, "bright_suppress") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)bright_suppress));
    }

    // lce_strength
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lce_strength", ParameterParserDataType::Float, (double)lce_strength));
    }
    else if (PARAMETER_STRCMP(__name, "lce_strength") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)lce_strength));
    }

    // p0
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("p0", ParameterParserDataType::Float, (double)p0));
    }
    else if (PARAMETER_STRCMP(__name, "p0") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)p0));
    }

    // p1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("p1", ParameterParserDataType::Float, (double)p1));
    }
    else if (PARAMETER_STRCMP(__name, "p1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)p1));
    }

    // dark_range
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dark_range", ParameterParserDataType::Float, (double)dark_range));
    }
    else if (PARAMETER_STRCMP(__name, "dark_range") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dark_range));
    }

    // bright_range
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("bright_range", ParameterParserDataType::Float, (double)bright_range));
    }
    else if (PARAMETER_STRCMP(__name, "bright_range") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)bright_range));
    }

    // dark_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dark_max", ParameterParserDataType::Float, (double)dark_max));
    }
    else if (PARAMETER_STRCMP(__name, "dark_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dark_max));
    }

    // bright_max
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("bright_max", ParameterParserDataType::Float, (double)bright_max));
    }
    else if (PARAMETER_STRCMP(__name, "bright_max") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)bright_max));
    }

    // dark_gamma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dark_gamma", ParameterParserDataType::Float, (double)dark_gamma));
    }
    else if (PARAMETER_STRCMP(__name, "dark_gamma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dark_gamma));
    }

    // bright_gamma
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("bright_gamma", ParameterParserDataType::Float, (double)bright_gamma));
    }
    else if (PARAMETER_STRCMP(__name, "bright_gamma") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)bright_gamma));
    }

    return __result;
}

bool ltm13_rgn_dataType::la_curve_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "la_curve") == 0)
    {
        if (__index < 65)
        {
            ParameterUtils::DoubleToString((double)la_curve[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 65; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)la_curve[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::la_curve_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "la_curve") == 0)
    {
        if (__index < 65)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                la_curve[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 65)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    la_curve[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::la_curve_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // la_curve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("la_curve", ParameterParserDataType::Int32, true, false, 65));
    }

    return __result;
}

bool ltm13_rgn_dataType::ltm_scale_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_scale") == 0)
    {
        if (__index < 65)
        {
            ParameterUtils::DoubleToString((double)ltm_scale[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 65; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ltm_scale[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::ltm_scale_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_scale") == 0)
    {
        if (__index < 65)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ltm_scale[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 65)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ltm_scale[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::ltm_scale_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ltm_scale
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_scale", ParameterParserDataType::Int32, true, false, 65));
    }

    return __result;
}

bool ltm13_rgn_dataType::lce_scale_pos_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lce_scale_pos") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)lce_scale_pos[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)lce_scale_pos[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::lce_scale_pos_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lce_scale_pos") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                lce_scale_pos[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    lce_scale_pos[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::lce_scale_pos_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lce_scale_pos
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lce_scale_pos", ParameterParserDataType::Int32, true, false, 17));
    }

    return __result;
}

bool ltm13_rgn_dataType::lce_scale_neg_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lce_scale_neg") == 0)
    {
        if (__index < 17)
        {
            ParameterUtils::DoubleToString((double)lce_scale_neg[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 17; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)lce_scale_neg[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::lce_scale_neg_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lce_scale_neg") == 0)
    {
        if (__index < 17)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                lce_scale_neg[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 17)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    lce_scale_neg[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool ltm13_rgn_dataType::lce_scale_neg_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lce_scale_neg
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lce_scale_neg", ParameterParserDataType::Int32, true, false, 17));
    }

    return __result;
}

bool mod_ltm13_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ltm13_rgn_data") == 0)
    {
        __result = ltm13_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_ltm13_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ltm13_rgn_data") == 0)
    {
        __result = ltm13_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_ltm13_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // ltm13_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm13_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ltm13_rgn_data") == 0)
    {
        __result = ltm13_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_ltm13_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_ltm13_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_ltm13_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_ltm13_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ltm13_aec_data") == 0)
    {
        if (__index < mod_ltm13_aec_dataCount)
        {
            __result = mod_ltm13_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_ltm13_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ltm13_aec_data") == 0)
    {
        if (__index < mod_ltm13_aec_dataCount)
        {
            __result = mod_ltm13_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_ltm13_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_ltm13_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_ltm13_aec_data", ParameterParserDataType::Structure, true, false, mod_ltm13_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_ltm13_aec_data") == 0)
    {
        if (__index < mod_ltm13_aec_dataCount)
        {
            __result = mod_ltm13_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_ltm13_aec_dataCount));
        }
    }

    return __result;
}

bool mod_ltm13_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_ltm13_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_ltm13_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_ltm13_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ltm13_hdr_aec_data") == 0)
    {
        if (__index < mod_ltm13_hdr_aec_dataCount)
        {
            __result = mod_ltm13_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_ltm13_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ltm13_hdr_aec_data") == 0)
    {
        if (__index < mod_ltm13_hdr_aec_dataCount)
        {
            __result = mod_ltm13_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_ltm13_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_ltm13_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_ltm13_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_ltm13_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_ltm13_hdr_aec_data") == 0)
    {
        if (__index < mod_ltm13_hdr_aec_dataCount)
        {
            __result = mod_ltm13_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_ltm13_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool chromatix_ltm13_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ltm13_drc_gain_data") == 0)
    {
        if (__index < mod_ltm13_drc_gain_dataCount)
        {
            __result = mod_ltm13_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_ltm13_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_ltm13_drc_gain_data") == 0)
    {
        if (__index < mod_ltm13_drc_gain_dataCount)
        {
            __result = mod_ltm13_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_ltm13_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_ltm13_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_ltm13_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_ltm13_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_ltm13_drc_gain_data") == 0)
    {
        if (__index < mod_ltm13_drc_gain_dataCount)
        {
            __result = mod_ltm13_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_ltm13_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_en") == 0)
    {
        ParameterUtils::DoubleToString((double)ltm_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "data_collect_en") == 0)
    {
        ParameterUtils::DoubleToString((double)data_collect_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "img_process_en") == 0)
    {
        ParameterUtils::DoubleToString((double)img_process_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "igamma_en") == 0)
    {
        ParameterUtils::DoubleToString((double)igamma_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "la_en") == 0)
    {
        ParameterUtils::DoubleToString((double)la_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "mask_filter_en") == 0)
    {
        ParameterUtils::DoubleToString((double)mask_filter_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ltm_scale_manual_curve_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)ltm_scale_manual_curve_enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "la_manual_curve_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)la_manual_curve_enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "c1") == 0)
    {
        ParameterUtils::DoubleToString((double)c1, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "c2") == 0)
    {
        ParameterUtils::DoubleToString((double)c2, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "c3") == 0)
    {
        ParameterUtils::DoubleToString((double)c3, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "c4") == 0)
    {
        ParameterUtils::DoubleToString((double)c4, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "wt_tab") == 0)
    {
        __result = wt_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "mask_filter_kernel_tab") == 0)
    {
        __result = mask_filter_kernel_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "mask_rect_curve_tab") == 0)
    {
        __result = mask_rect_curve_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "ltm_curve_tab") == 0)
    {
        __result = ltm_curve_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lce_thd") == 0)
    {
        ParameterUtils::DoubleToString((double)lce_thd, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "r0") == 0)
    {
        ParameterUtils::DoubleToString((double)r0, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "r1") == 0)
    {
        ParameterUtils::DoubleToString((double)r1, __value, __size);
        __result = true;
    }

    return __result;
}

bool chromatix_ltm13_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ltm_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "data_collect_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            data_collect_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "img_process_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            img_process_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "igamma_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            igamma_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "la_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            la_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "mask_filter_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            mask_filter_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ltm_scale_manual_curve_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ltm_scale_manual_curve_enable = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "la_manual_curve_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            la_manual_curve_enable = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "c1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            c1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "c2") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            c2 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "c3") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            c3 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "c4") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            c4 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "wt_tab") == 0)
    {
        __result = wt_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "mask_filter_kernel_tab") == 0)
    {
        __result = mask_filter_kernel_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "mask_rect_curve_tab") == 0)
    {
        __result = mask_rect_curve_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "ltm_curve_tab") == 0)
    {
        __result = ltm_curve_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lce_thd") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lce_thd = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "r0") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            r0 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "r1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            r1 = (float)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ltm_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_en", ParameterParserDataType::UInt32, (double)ltm_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ltm_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ltm_en, 0));
    }

    // data_collect_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("data_collect_en", ParameterParserDataType::UInt32, (double)data_collect_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "data_collect_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)data_collect_en, 0));
    }

    // img_process_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("img_process_en", ParameterParserDataType::UInt32, (double)img_process_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "img_process_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)img_process_en, 0));
    }

    // igamma_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("igamma_en", ParameterParserDataType::UInt32, (double)igamma_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "igamma_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)igamma_en, 0));
    }

    // la_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("la_en", ParameterParserDataType::UInt32, (double)la_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "la_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)la_en, 0));
    }

    // mask_filter_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mask_filter_en", ParameterParserDataType::UInt32, (double)mask_filter_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "mask_filter_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)mask_filter_en, 0));
    }

    // ltm_scale_manual_curve_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_scale_manual_curve_enable", ParameterParserDataType::UInt32, (double)ltm_scale_manual_curve_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ltm_scale_manual_curve_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ltm_scale_manual_curve_enable, 0));
    }

    // la_manual_curve_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("la_manual_curve_enable", ParameterParserDataType::UInt32, (double)la_manual_curve_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "la_manual_curve_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)la_manual_curve_enable, 0));
    }

    // c1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("c1", ParameterParserDataType::Float, (double)c1));
    }
    else if (PARAMETER_STRCMP(__name, "c1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)c1));
    }

    // c2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("c2", ParameterParserDataType::Float, (double)c2));
    }
    else if (PARAMETER_STRCMP(__name, "c2") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)c2));
    }

    // c3
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("c3", ParameterParserDataType::Float, (double)c3));
    }
    else if (PARAMETER_STRCMP(__name, "c3") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)c3));
    }

    // c4
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("c4", ParameterParserDataType::Float, (double)c4));
    }
    else if (PARAMETER_STRCMP(__name, "c4") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)c4));
    }

    // wt_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("wt_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "wt_tab") == 0)
    {
        __result = wt_tab.GetInfo(&__path[__pos], __info);
    }

    // mask_filter_kernel_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mask_filter_kernel_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "mask_filter_kernel_tab") == 0)
    {
        __result = mask_filter_kernel_tab.GetInfo(&__path[__pos], __info);
    }

    // mask_rect_curve_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mask_rect_curve_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "mask_rect_curve_tab") == 0)
    {
        __result = mask_rect_curve_tab.GetInfo(&__path[__pos], __info);
    }

    // ltm_curve_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_curve_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ltm_curve_tab") == 0)
    {
        __result = ltm_curve_tab.GetInfo(&__path[__pos], __info);
    }

    // lce_thd
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lce_thd", ParameterParserDataType::UInt32, (double)lce_thd, 0));
    }
    else if (PARAMETER_STRCMP(__name, "lce_thd") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)lce_thd, 0));
    }

    // r0
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("r0", ParameterParserDataType::Float, (double)r0));
    }
    else if (PARAMETER_STRCMP(__name, "r0") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)r0));
    }

    // r1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("r1", ParameterParserDataType::Float, (double)r1));
    }
    else if (PARAMETER_STRCMP(__name, "r1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)r1));
    }

    return __result;
}

bool chromatix_ltm13_reserveType::wt_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "wt") == 0)
    {
        if (__index < 24)
        {
            ParameterUtils::DoubleToString((double)wt[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 24; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)wt[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::wt_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "wt") == 0)
    {
        if (__index < 24)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                wt[__index] = (UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 24)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    wt[__index] = (UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::wt_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // wt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("wt", ParameterParserDataType::UInt32, true, false, 24));
    }

    return __result;
}

bool chromatix_ltm13_reserveType::mask_filter_kernel_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mask_filter_kernel") == 0)
    {
        if (__index < 6)
        {
            ParameterUtils::DoubleToString((double)mask_filter_kernel[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 6; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)mask_filter_kernel[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::mask_filter_kernel_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mask_filter_kernel") == 0)
    {
        if (__index < 6)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                mask_filter_kernel[__index] = (UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 6)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    mask_filter_kernel[__index] = (UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::mask_filter_kernel_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mask_filter_kernel
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mask_filter_kernel", ParameterParserDataType::UInt32, true, false, 6));
    }

    return __result;
}

bool chromatix_ltm13_reserveType::mask_rect_curve_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mask_rect_curve") == 0)
    {
        if (__index < 65)
        {
            ParameterUtils::DoubleToString((double)mask_rect_curve[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 65; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)mask_rect_curve[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::mask_rect_curve_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mask_rect_curve") == 0)
    {
        if (__index < 65)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                mask_rect_curve[__index] = (INT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 65)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    mask_rect_curve[__index] = (INT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::mask_rect_curve_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mask_rect_curve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mask_rect_curve", ParameterParserDataType::Int32, true, false, 65));
    }

    return __result;
}

bool chromatix_ltm13_reserveType::ltm_curve_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_curve") == 0)
    {
        if (__index < 65)
        {
            ParameterUtils::DoubleToString((double)ltm_curve[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 65; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ltm_curve[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::ltm_curve_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_curve") == 0)
    {
        if (__index < 65)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ltm_curve[__index] = (INT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 65)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ltm_curve[__index] = (INT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13_reserveType::ltm_curve_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ltm_curve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_curve", ParameterParserDataType::Int32, true, false, 65));
    }

    return __result;
}

bool chromatix_ltm13Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ltm13_reserve") == 0)
    {
        __result = chromatix_ltm13_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ltm13_core") == 0)
    {
        __result = chromatix_ltm13_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_ltm13Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ltm13_reserve") == 0)
    {
        __result = chromatix_ltm13_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ltm13_core") == 0)
    {
        __result = chromatix_ltm13_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_ltm13Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_ltm13_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_ltm13_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ltm13_reserve") == 0)
    {
        __result = chromatix_ltm13_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_ltm13_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_ltm13_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_ltm13_core") == 0)
    {
        __result = chromatix_ltm13_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_ltm13Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)ltm_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ltm13Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ltm_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ltm_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ltm13Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ltm_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ltm_enable", ParameterParserDataType::Int32, (double)ltm_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ltm_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)ltm_enable, 0));
    }

    return __result;
}

bool chromatix_ltm13Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ltm13Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ltm13Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_ltm13Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_ltm13Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_ltm13Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_ltm13Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_ltm13Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 3));
    }

    return __result;
}

bool chromatix_ltm13Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_ltm13Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_ltm13Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_ltm13Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_ltm13TypeClass::chromatix_ltm13TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_ltm13_reserve);
    PARAMETER_INITIALIZE(chromatix_ltm13_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_ltm13TypeClass::chromatix_ltm13TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_ltm13_reserve);
    PARAMETER_INITIALIZE(chromatix_ltm13_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_ltm13TypeClass::~chromatix_ltm13TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_ltm13TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "ltm13_ipe")) == 0)
    {
        name = "ltm13_ipe";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ltm13_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ltm13_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(la_curve_tab);
    PARAMETER_INITIALIZE(ltm_scale_tab);
    PARAMETER_INITIALIZE(lce_scale_pos_tab);
    PARAMETER_INITIALIZE(lce_scale_neg_tab);
    PARAMETER_INITIALIZE(y_ratio_max);
    PARAMETER_INITIALIZE(ltm_strength);
    PARAMETER_INITIALIZE(exp_atten_start);
    PARAMETER_INITIALIZE(exp_atten_end);
    PARAMETER_INITIALIZE(dark_boost);
    PARAMETER_INITIALIZE(bright_suppress);
    PARAMETER_INITIALIZE(lce_strength);
    PARAMETER_INITIALIZE(p0);
    PARAMETER_INITIALIZE(p1);
    PARAMETER_INITIALIZE(dark_range);
    PARAMETER_INITIALIZE(bright_range);
    PARAMETER_INITIALIZE(dark_max);
    PARAMETER_INITIALIZE(bright_max);
    PARAMETER_INITIALIZE(dark_gamma);
    PARAMETER_INITIALIZE(bright_gamma);

    result = la_curve_tab.Load(entry, alignment);
    if (result)
    {
        result = ltm_scale_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = lce_scale_pos_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = lce_scale_neg_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, y_ratio_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, ltm_strength, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, exp_atten_start, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, exp_atten_end, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dark_boost, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, bright_suppress, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lce_strength, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, p0, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, p1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dark_range, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, bright_range, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dark_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, bright_max, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dark_gamma, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, bright_gamma, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ltm13_rgn_dataType_la_curve_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ltm13_rgn_dataType::la_curve_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(la_curve);

    result = entry->ReadArray(la_curve, 65, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ltm13_rgn_dataType_ltm_scale_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ltm13_rgn_dataType::ltm_scale_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ltm_scale);

    result = entry->ReadArray(ltm_scale, 65, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ltm13_rgn_dataType_lce_scale_pos_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ltm13_rgn_dataType::lce_scale_pos_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lce_scale_pos);

    result = entry->ReadArray(lce_scale_pos, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load ltm13_rgn_dataType_lce_scale_neg_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ltm13_rgn_dataType::lce_scale_neg_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lce_scale_neg);

    result = entry->ReadArray(lce_scale_neg, 17, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ltm13_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ltm13_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(ltm13_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = ltm13_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ltm13_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ltm13_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ltm13_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ltm13_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_ltm13_aec_data);


    // Reading Array mod_ltm13_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_ltm13_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_ltm13_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_ltm13_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_ltm13_aec_dataDupInfo = pointerEntry->GetDupObject(mod_ltm13_aec_dataCount, file, line);
            if (mod_ltm13_aec_dataDupInfo != nullptr && mod_ltm13_aec_dataDupInfo->Object != nullptr)
            {
                mod_ltm13_aec_data = (mod_ltm13_aec_dataType*)mod_ltm13_aec_dataDupInfo->Object;
                if (mod_ltm13_aec_data == nullptr)
                {
                    if (mod_ltm13_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ltm13_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_ltm13_aec_dataDupInfo->File, mod_ltm13_aec_dataDupInfo->Line, mod_ltm13_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ltm13_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_ltm13_aec_dataDupInfo->Line, mod_ltm13_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_ltm13_aec_data == nullptr)
            {
                if (result && mod_ltm13_aec_dataCount > 0)
                {
                    mod_ltm13_aec_data = PARAMETER_NEW mod_ltm13_aec_dataType[mod_ltm13_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_ltm13_aec_data, mod_ltm13_aec_dataCount, file, line);
                }
                if (!result || mod_ltm13_aec_data == nullptr)
                {
                    if (mod_ltm13_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_ltm13_aec_data\n");
                    }
                    mod_ltm13_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_ltm13_aec_dataCount; i++)
                {
                    result = mod_ltm13_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_ltm13_aec_data == nullptr)
        {
            mod_ltm13_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ltm13_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ltm13_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_ltm13_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_ltm13_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_ltm13_hdr_aec_data);


    // Reading Array mod_ltm13_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_ltm13_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_ltm13_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_ltm13_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_ltm13_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_ltm13_hdr_aec_dataCount, file, line);
            if (mod_ltm13_hdr_aec_dataDupInfo != nullptr && mod_ltm13_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_ltm13_hdr_aec_data = (mod_ltm13_hdr_aec_dataType*)mod_ltm13_hdr_aec_dataDupInfo->Object;
                if (mod_ltm13_hdr_aec_data == nullptr)
                {
                    if (mod_ltm13_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ltm13_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_ltm13_hdr_aec_dataDupInfo->File, mod_ltm13_hdr_aec_dataDupInfo->Line, mod_ltm13_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ltm13_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_ltm13_hdr_aec_dataDupInfo->Line, mod_ltm13_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_ltm13_hdr_aec_data == nullptr)
            {
                if (result && mod_ltm13_hdr_aec_dataCount > 0)
                {
                    mod_ltm13_hdr_aec_data = PARAMETER_NEW mod_ltm13_hdr_aec_dataType[mod_ltm13_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_ltm13_hdr_aec_data, mod_ltm13_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_ltm13_hdr_aec_data == nullptr)
                {
                    if (mod_ltm13_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_ltm13_hdr_aec_data\n");
                    }
                    mod_ltm13_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_ltm13_hdr_aec_dataCount; i++)
                {
                    result = mod_ltm13_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_ltm13_hdr_aec_data == nullptr)
        {
            mod_ltm13_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_ltm13_drc_gain_data);


    // Reading Array mod_ltm13_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_ltm13_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_ltm13_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_ltm13_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_ltm13_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_ltm13_drc_gain_dataCount, file, line);
            if (mod_ltm13_drc_gain_dataDupInfo != nullptr && mod_ltm13_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_ltm13_drc_gain_data = (mod_ltm13_drc_gain_dataType*)mod_ltm13_drc_gain_dataDupInfo->Object;
                if (mod_ltm13_drc_gain_data == nullptr)
                {
                    if (mod_ltm13_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ltm13_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_ltm13_drc_gain_dataDupInfo->File, mod_ltm13_drc_gain_dataDupInfo->Line, mod_ltm13_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_ltm13_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_ltm13_drc_gain_dataDupInfo->Line, mod_ltm13_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_ltm13_drc_gain_data == nullptr)
            {
                if (result && mod_ltm13_drc_gain_dataCount > 0)
                {
                    mod_ltm13_drc_gain_data = PARAMETER_NEW mod_ltm13_drc_gain_dataType[mod_ltm13_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_ltm13_drc_gain_data, mod_ltm13_drc_gain_dataCount, file, line);
                }
                if (!result || mod_ltm13_drc_gain_data == nullptr)
                {
                    if (mod_ltm13_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_ltm13_drc_gain_data\n");
                    }
                    mod_ltm13_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_ltm13_drc_gain_dataCount; i++)
                {
                    result = mod_ltm13_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_ltm13_drc_gain_data == nullptr)
        {
            mod_ltm13_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ltm_en);
    PARAMETER_INITIALIZE(data_collect_en);
    PARAMETER_INITIALIZE(img_process_en);
    PARAMETER_INITIALIZE(igamma_en);
    PARAMETER_INITIALIZE(la_en);
    PARAMETER_INITIALIZE(mask_filter_en);
    PARAMETER_INITIALIZE(ltm_scale_manual_curve_enable);
    PARAMETER_INITIALIZE(la_manual_curve_enable);
    PARAMETER_INITIALIZE(c1);
    PARAMETER_INITIALIZE(c2);
    PARAMETER_INITIALIZE(c3);
    PARAMETER_INITIALIZE(c4);
    PARAMETER_INITIALIZE(wt_tab);
    PARAMETER_INITIALIZE(mask_filter_kernel_tab);
    PARAMETER_INITIALIZE(mask_rect_curve_tab);
    PARAMETER_INITIALIZE(ltm_curve_tab);
    PARAMETER_INITIALIZE(lce_thd);
    PARAMETER_INITIALIZE(r0);
    PARAMETER_INITIALIZE(r1);

    SYMBOL_TABLE_ENTRY_READ(entry, result, ltm_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, data_collect_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, img_process_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, igamma_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, la_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, mask_filter_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, ltm_scale_manual_curve_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, la_manual_curve_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, c1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, c2, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, c3, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, c4, alignment)
    if (result)
    {
        result = wt_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = mask_filter_kernel_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = mask_rect_curve_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = ltm_curve_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, lce_thd, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, r0, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, r1, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13_reserveType_wt_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13_reserveType::wt_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(wt);

    result = entry->ReadArray(wt, 24, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13_reserveType_mask_filter_kernel_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13_reserveType::mask_filter_kernel_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mask_filter_kernel);

    result = entry->ReadArray(mask_filter_kernel, 6, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13_reserveType_mask_rect_curve_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13_reserveType::mask_rect_curve_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mask_rect_curve);

    result = entry->ReadArray(mask_rect_curve, 65, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13_reserveType_ltm_curve_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13_reserveType::ltm_curve_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ltm_curve);

    result = entry->ReadArray(ltm_curve, 65, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_ltm13Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_ltm13_reserve);
    PARAMETER_INITIALIZE(chromatix_ltm13_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_ltm13_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_ltm13_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ltm_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, ltm_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 3; i++)
    {
        result = chromatix_ltm13Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ltm13_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ltm13_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ltm13_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ltm13_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_ltm13_aec_data))
    {
        PARAMETER_DELETE[] mod_ltm13_aec_data;
    }
    mod_ltm13_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ltm13_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ltm13_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_ltm13_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_ltm13_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_ltm13_hdr_aec_dataCount; i++)
    {
        mod_ltm13_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_ltm13_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_ltm13_hdr_aec_data;
    }
    mod_ltm13_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_ltm13_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ltm13_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_ltm13_drc_gain_dataCount; i++)
    {
        mod_ltm13_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_ltm13_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_ltm13_drc_gain_data;
    }
    mod_ltm13_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_ltm13Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ltm13Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_ltm13_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ltm13Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ltm13Type::Release()
{
    ((chromatix_ltm13TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_ltm13Type::GetModified()
{
    return ((chromatix_ltm13TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_ltm13TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_ltm13TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_ltm13TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_ltm13TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_ltm13TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_ltm13TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_ltm13TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_ltm13TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_ltm13TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ltm13TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_ltm13TypeClass::Release()
{
    ParameterModule::Release();
}

LTM_1_3_0_NAMESPACE_END
